==> aws-cdk.aws-athena-1.147.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_athena_CfnPreparedStatementProps(p) {
}
function _aws_cdk_aws_athena_CfnNamedQueryProps(p) {
}
function _aws_cdk_aws_athena_CfnDataCatalogProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_athena_CfnPreparedStatement(p) {
}
function _aws_cdk_aws_athena_CfnNamedQuery(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroupProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_athena_CfnDataCatalog(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup_EncryptionConfigurationProperty(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup_EngineVersionProperty(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup_ResultConfigurationProperty(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup_ResultConfigurationUpdatesProperty(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup_WorkGroupConfigurationProperty(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup_WorkGroupConfigurationUpdatesProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_athena_CfnPreparedStatementProps, _aws_cdk_aws_athena_CfnNamedQueryProps, _aws_cdk_aws_athena_CfnDataCatalogProps, _aws_cdk_aws_athena_CfnPreparedStatement, _aws_cdk_aws_athena_CfnNamedQuery, _aws_cdk_aws_athena_CfnWorkGroupProps, _aws_cdk_aws_athena_CfnDataCatalog, _aws_cdk_aws_athena_CfnWorkGroup, _aws_cdk_aws_athena_CfnWorkGroup_EncryptionConfigurationProperty, _aws_cdk_aws_athena_CfnWorkGroup_EngineVersionProperty, _aws_cdk_aws_athena_CfnWorkGroup_ResultConfigurationProperty, _aws_cdk_aws_athena_CfnWorkGroup_ResultConfigurationUpdatesProperty, _aws_cdk_aws_athena_CfnWorkGroup_WorkGroupConfigurationProperty, _aws_cdk_aws_athena_CfnWorkGroup_WorkGroupConfigurationUpdatesProperty };
module.exports.DeprecationError = DeprecationError;

==> aws-cdk.aws-athena-1.152.0.tar.gz: package/.warnings.jsii.js <==
function _aws_cdk_aws_athena_CfnPreparedStatementProps(p) {
}
function _aws_cdk_aws_athena_CfnNamedQueryProps(p) {
}
function _aws_cdk_aws_athena_CfnDataCatalogProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_athena_CfnNamedQuery(p) {
}
function _aws_cdk_aws_athena_CfnPreparedStatement(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroupProps(p) {
    if (p == null)
        return;
    visitedObjects.add(p);
    if (!visitedObjects.has(p.tags))
        require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
    visitedObjects.delete(p);
}
function _aws_cdk_aws_athena_CfnDataCatalog(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup_EncryptionConfigurationProperty(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup_EngineVersionProperty(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup_ResultConfigurationProperty(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup_ResultConfigurationUpdatesProperty(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup_WorkGroupConfigurationProperty(p) {
}
function _aws_cdk_aws_athena_CfnWorkGroup_WorkGroupConfigurationUpdatesProperty(p) {
}
function print(name, deprecationMessage) {
    const deprecated = process.env.JSII_DEPRECATED;
    const deprecationMode = ["warn", "fail", "quiet"].includes(deprecated) ? deprecated : "warn";
    const message = `${name} is deprecated.\n  ${deprecationMessage}\n  This API will be removed in the next major release.`;
    switch (deprecationMode) {
        case "fail":
            throw new DeprecationError(message);
        case "warn":
            console.warn("[WARNING]", message);
            break;
    }
}
const visitedObjects = new Set();
class DeprecationError extends Error {
}
module.exports = { print, _aws_cdk_aws_athena_CfnPreparedStatementProps, _aws_cdk_aws_athena_CfnNamedQueryProps, _aws_cdk_aws_athena_CfnDataCatalogProps, _aws_cdk_aws_athena_CfnNamedQuery, _aws_cdk_aws_athena_CfnPreparedStatement, _aws_cdk_aws_athena_CfnWorkGroupProps, _aws_cdk_aws_athena_CfnDataCatalog, _aws_cdk_aws_athena_CfnWorkGroup, _aws_cdk_aws_athena_CfnWorkGroup_EncryptionConfigurationProperty, _aws_cdk_aws_athena_CfnWorkGroup_EngineVersionProperty, _aws_cdk_aws_athena_CfnWorkGroup_ResultConfigurationProperty, _aws_cdk_aws_athena_CfnWorkGroup_ResultConfigurationUpdatesProperty, _aws_cdk_aws_athena_CfnWorkGroup_WorkGroupConfigurationProperty, _aws_cdk_aws_athena_CfnWorkGroup_WorkGroupConfigurationUpdatesProperty };
module.exports.DeprecationError = DeprecationError;
